@@ -19,8 +19,6 @@
  */
 package com.eteks.sweethome3d.model;
 
-import java.beans.PropertyChangeListener;
-import java.beans.PropertyChangeSupport;
 import java.io.IOException;
 import java.io.ObjectInputStream;
 import java.util.Calendar;
@@ -37,16 +35,16 @@ public class Camera extends HomeObject {
    * @author Emmanuel Puybaret
    * @since 3.0
    */
-  public enum Lens {PINHOLE, NORMAL, FISHEYE, SPHERICAL} 
+  public enum Lens {PINHOLE, NORMAL, FISHEYE, SPHERICAL}
 
   /**
-   * The properties of a camera that may change. <code>PropertyChangeListener</code>s added 
+   * The properties of a camera that may change. <code>PropertyChangeListener</code>s added
    * to a camera will be notified under a property name equal to the string value of one these properties.
    */
   public enum Property {NAME, X, Y, Z, YAW, PITCH, FIELD_OF_VIEW, TIME, LENS}
-  
+
   private static final long serialVersionUID = 1L;
-  
+
   private String              name;
   private float               x;
   private float               y;
@@ -56,12 +54,10 @@ public class Camera extends HomeObject {
   private float               fieldOfView;
   private long                time;
   private transient Lens      lens;
-  // Lens is saved as a string to be able to keep backward compatibility 
+  // Lens is saved as a string to be able to keep backward compatibility
   // if new constants are added to Lens enum in future versions
   private String              lensName;
 
-  private transient PropertyChangeSupport propertyChangeSupport = new PropertyChangeSupport(this);
-
   /**
    * Creates a camera at given location and angles at midday and using a pinhole lens.
    */
@@ -69,12 +65,31 @@ public class Camera extends HomeObject {
     this(x, y, z, yaw, pitch, fieldOfView, midday(), Lens.PINHOLE);
   }
 
+  /**
+   * Creates a camera at given location and angles at midday and using a pinhole lens.
+   * @since 6.4
+   */
+  public Camera(String id, float x, float y, float z, float yaw, float pitch, float fieldOfView) {
+    this(id, x, y, z, yaw, pitch, fieldOfView, midday(), Lens.PINHOLE);
+  }
+
   /**
    * Creates a camera at given location and angles.
    * @since 3.0
    */
-  public Camera(float x, float y, float z, float yaw, float pitch, float fieldOfView, 
+  public Camera(float x, float y, float z, float yaw, float pitch, float fieldOfView,
                 long time, Lens lens) {
+    this(createId("camera"), x, y, z, yaw, pitch, fieldOfView, time, lens);
+  }
+
+
+  /**
+   * Creates a camera at given location and angles.
+   * @since 6.4
+   */
+  public Camera(String id, float x, float y, float z, float yaw, float pitch, float fieldOfView,
+                long time, Lens lens) {
+    super(id);
     this.x = x;
     this.y = y;
     this.z = z;
@@ -96,47 +111,25 @@ public class Camera extends HomeObject {
     midday.set(Calendar.MILLISECOND, 0);
     return midday.getTimeInMillis();
   }
-  
+
   /**
-   * Initializes new camera transient fields  
+   * Initializes new camera transient fields
    * and reads its properties from <code>in</code> stream with default reading method.
    */
   private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException {
-    this.propertyChangeSupport = new PropertyChangeSupport(this);
     this.time = midday();
     this.lens = Lens.PINHOLE;
     in.defaultReadObject();
     try {
-      // Read lens from a string 
+      // Read lens from a string
       if (this.lensName != null) {
         this.lens = Lens.valueOf(this.lensName);
       }
     } catch (IllegalArgumentException ex) {
-      // Ignore malformed enum constant 
+      // Ignore malformed enum constant
     }
   }
 
-  private void writeObject(java.io.ObjectOutputStream out) throws IOException {
-    // Write lens as a string to be able to read lens later 
-    // even if enum changed in later versions
-    this.lensName = this.lens.name();
-    out.defaultWriteObject();
-  }
-  
-  /**
-   * Adds the property change <code>listener</code> in parameter to this camera.
-   */
-  public void addPropertyChangeListener(PropertyChangeListener listener) {
-    this.propertyChangeSupport.addPropertyChangeListener(listener);
-  }
-
-  /**
-   * Removes the property change <code>listener</code> in parameter from this camera.
-   */
-  public void removePropertyChangeListener(PropertyChangeListener listener) {
-    this.propertyChangeSupport.removePropertyChangeListener(listener);
-  }
-
   /**
    * Returns the name of this camera.
    * @since 3.0
@@ -146,7 +139,7 @@ public class Camera extends HomeObject {
   }
 
   /**
-   * Sets the name of this camera and notifies listeners of this change. 
+   * Sets the name of this camera and notifies listeners of this change.
    * @since 3.0
    */
   public void setName(String name) {
@@ -154,7 +147,7 @@ public class Camera extends HomeObject {
         && (name == null || !name.equals(this.name))) {
       String oldName = this.name;
       this.name = name;
-      this.propertyChangeSupport.firePropertyChange(Property.NAME.name(), oldName, name);
+      firePropertyChange(Property.NAME.name(), oldName, name);
     }
   }
 
@@ -167,16 +160,16 @@ public class Camera extends HomeObject {
 
   /**
    * Sets the yaw angle in radians of this camera and notifies listeners of this change.
-   * Yaw axis is vertical axis. 
+   * Yaw axis is vertical axis.
    */
   public void setYaw(float yaw) {
     if (yaw != this.yaw) {
       float oldYaw = this.yaw;
       this.yaw = yaw;
-      this.propertyChangeSupport.firePropertyChange(Property.YAW.name(), oldYaw, yaw);
+      firePropertyChange(Property.YAW.name(), oldYaw, yaw);
     }
   }
-  
+
   /**
    * Returns the pitch angle in radians of this camera.
    */
@@ -186,13 +179,13 @@ public class Camera extends HomeObject {
 
   /**
    * Sets the pitch angle in radians of this camera and notifies listeners of this change.
-   * Pitch axis is horizontal transverse axis. 
+   * Pitch axis is horizontal transverse axis.
    */
   public void setPitch(float pitch) {
     if (pitch != this.pitch) {
       float oldPitch = this.pitch;
       this.pitch = pitch;
-      this.propertyChangeSupport.firePropertyChange(Property.PITCH.name(), oldPitch, pitch);
+      firePropertyChange(Property.PITCH.name(), oldPitch, pitch);
     }
   }
 
@@ -210,7 +203,7 @@ public class Camera extends HomeObject {
     if (fieldOfView != this.fieldOfView) {
       float oldFieldOfView = this.fieldOfView;
       this.fieldOfView = fieldOfView;
-      this.propertyChangeSupport.firePropertyChange(Property.FIELD_OF_VIEW.name(), oldFieldOfView, fieldOfView);
+      firePropertyChange(Property.FIELD_OF_VIEW.name(), oldFieldOfView, fieldOfView);
     }
   }
 
@@ -228,10 +221,10 @@ public class Camera extends HomeObject {
     if (x != this.x) {
       float oldX = this.x;
       this.x = x;
-      this.propertyChangeSupport.firePropertyChange(Property.X.name(), oldX, x);
+      firePropertyChange(Property.X.name(), oldX, x);
     }
   }
-  
+
   /**
    * Returns the ordinate of this camera.
    */
@@ -246,17 +239,17 @@ public class Camera extends HomeObject {
     if (y != this.y) {
       float oldY = this.y;
       this.y = y;
-      this.propertyChangeSupport.firePropertyChange(Property.Y.name(), oldY, y);
+      firePropertyChange(Property.Y.name(), oldY, y);
     }
   }
-  
+
   /**
    * Returns the elevation of this camera.
    */
   public float getZ() {
     return this.z;
   }
-  
+
   /**
    * Sets the elevation of this camera and notifies listeners of this change.
    */
@@ -264,7 +257,7 @@ public class Camera extends HomeObject {
     if (z != this.z) {
       float oldZ = this.z;
       this.z = z;
-      this.propertyChangeSupport.firePropertyChange(Property.Z.name(), oldZ, z);
+      firePropertyChange(Property.Z.name(), oldZ, z);
     }
   }
 
@@ -278,24 +271,23 @@ public class Camera extends HomeObject {
   }
 
   /**
-   * Sets the use time in milliseconds since the Epoch in UTC time zone, 
-   * and notifies listeners of this change. 
+   * Sets the use time in milliseconds since the Epoch in UTC time zone,
+   * and notifies listeners of this change.
    * @since 3.0
    */
   public void setTime(long time) {
     if (this.time != time) {
       long oldTime = this.time;
       this.time = time;
-      this.propertyChangeSupport.firePropertyChange(Property.TIME.name(), 
-          oldTime, time);
+      firePropertyChange(Property.TIME.name(), oldTime, time);
     }
   }
 
   /**
-   * Returns a time expressed in UTC time zone converted to the given time zone. 
+   * Returns a time expressed in UTC time zone converted to the given time zone.
    * @since 3.0
    */
-  public static long convertTimeToTimeZone(long utcTime, String timeZone) { 
+  public static long convertTimeToTimeZone(long utcTime, String timeZone) {
     Calendar utcCalendar = new GregorianCalendar(TimeZone.getTimeZone("UTC"));
     utcCalendar.setTimeInMillis(utcTime);
     Calendar convertedCalendar = new GregorianCalendar(TimeZone.getTimeZone(timeZone));
@@ -316,7 +308,7 @@ public class Camera extends HomeObject {
   public Lens getLens() {
     return this.lens;
   }
-  
+
   /**
    * Sets the lens of this camera and notifies listeners of this change.
    * @since 3.0
@@ -325,7 +317,8 @@ public class Camera extends HomeObject {
     if (lens != this.lens) {
       Lens oldLens = this.lens;
       this.lens = lens;
-      this.propertyChangeSupport.firePropertyChange(Property.LENS.name(), oldLens, lens);
+      this.lensName = this.lens.name();
+      firePropertyChange(Property.LENS.name(), oldLens, lens);
     }
   }
 
@@ -341,15 +334,13 @@ public class Camera extends HomeObject {
     setPitch(camera.getPitch());
     setFieldOfView(camera.getFieldOfView());
   }
-  
+
   /**
    * Returns a clone of this camera.
    * @since 2.3
    */
   @Override
   public Camera clone() {
-    Camera clone = (Camera)super.clone();
-    clone.propertyChangeSupport = new PropertyChangeSupport(clone);
-    return clone;
+    return (Camera)super.clone();
   }
 }
