@@ -41,8 +41,6 @@ import java.util.List;
 public class HomeFurnitureGroup extends HomePieceOfFurniture {
   private static final long serialVersionUID = 1L;
 
-  private static final float [][] IDENTITY = new float [][] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}};
-
   private List<HomePieceOfFurniture> furniture;
   private boolean                    resizable;
   private boolean                    deformable;
@@ -118,7 +116,10 @@ public class HomeFurnitureGroup extends HomePieceOfFurniture {
     }
 
     setName(name);
+    setCatalogId(null);
     setDescription(null);
+    setInformation(null);
+    setCreator(null);
     setNameVisible(false);
     setNameXOffset(0);
     setNameYOffset(0);
@@ -362,20 +363,20 @@ public class HomeFurnitureGroup extends HomePieceOfFurniture {
   }
 
   /**
-   * Returns <code>null</code>.
+   * Returns the catalog ID of this group.
    */
   @Override
   public String getCatalogId() {
-    return null;
+    return super.getCatalogId();
   }
 
   /**
-   * Returns <code>null</code>.
+   * Returns the information associated with this group.
    * @since 4.2
    */
   @Override
   public String getInformation() {
-    return null;
+    return super.getInformation();
   }
 
   /**
@@ -538,6 +539,14 @@ public class HomeFurnitureGroup extends HomePieceOfFurniture {
     return null;
   }
 
+  /**
+   * @throws IllegalStateException
+   * @since 6.5
+   */
+  public void setIcon(Content icon) {
+    throw new IllegalStateException("Can't set icon of a group");
+  }
+
   /**
    * Returns <code>null</code>.
    */
@@ -546,6 +555,14 @@ public class HomeFurnitureGroup extends HomePieceOfFurniture {
     return null;
   }
 
+  /**
+   * @throws IllegalStateException
+   * @since 6.5
+   */
+  public void setPlanIcon(Content planIcon) {
+    throw new IllegalStateException("Can't set plan icon of a group");
+  }
+
   /**
    * Returns <code>null</code>.
    */
@@ -556,10 +573,10 @@ public class HomeFurnitureGroup extends HomePieceOfFurniture {
 
   /**
    * @throws IllegalStateException
+   * @since 6.5
    */
-  @Override
-  public void setModelSize(Long modelSize) {
-    throw new IllegalStateException("Can't set model size of a group");
+  public void setModel(Content model) {
+    throw new IllegalStateException("Can't set model of a group");
   }
 
   /**
@@ -571,12 +588,30 @@ public class HomeFurnitureGroup extends HomePieceOfFurniture {
     return null;
   }
 
+  /**
+   * @throws IllegalStateException
+   * @since 5.5
+   */
+  @Override
+  public void setModelSize(Long modelSize) {
+    throw new IllegalStateException("Can't set model size of a group");
+  }
+
   /**
    * Returns an identity matrix.
    */
   @Override
   public float [][] getModelRotation() {
-    return IDENTITY;
+    return IDENTITY_ROTATION;
+  }
+
+  /**
+   * @throws IllegalStateException
+   * @since 6.5
+   */
+  @Override
+  public void setModelRotation(float [][] modelRotation) {
+    throw new IllegalStateException("Can't set model rotation of a group");
   }
 
   /**
@@ -588,6 +623,23 @@ public class HomeFurnitureGroup extends HomePieceOfFurniture {
     return true;
   }
 
+  /**
+   * Returns <code>false</code>.
+   */
+  @Override
+  public boolean isBackFaceShown() {
+    return false;
+  }
+
+  /**
+   * @throws IllegalStateException
+   * @since 6.5
+   */
+  @Override
+  public void setBackFaceShown(boolean backFaceShown) {
+    throw new IllegalStateException("Can't set back face shown attribute of a group");
+  }
+
   /**
    * Returns <code>null</code>.
    * @since 6.0
@@ -599,6 +651,7 @@ public class HomeFurnitureGroup extends HomePieceOfFurniture {
 
   /**
    * Sets the transformations of this group.
+   * @since 6.0
    */
   @Override
   public void setModelTransformations(Transformation [] modelTransformations) {
@@ -637,12 +690,21 @@ public class HomeFurnitureGroup extends HomePieceOfFurniture {
   }
 
   /**
-   * Returns <code>null</code>.
+   * @throws IllegalStateException
+   * @since 6.5
+   */
+  @Override
+  public void setStaircaseCutOutShape(String staircaseCutOutShape) {
+    throw new IllegalStateException("Can't set staircase cut out shape of a group");
+  }
+
+  /**
+   * Returns the creator set for this group.
    * @since 4.2
    */
   @Override
   public String getCreator() {
-    return null;
+    return super.getCreator();
   }
 
   /**
@@ -750,14 +812,6 @@ public class HomeFurnitureGroup extends HomePieceOfFurniture {
     return priceValueAddedTaxIncluded;
   }
 
-  /**
-   * Returns <code>false</code>.
-   */
-  @Override
-  public boolean isBackFaceShown() {
-    return false;
-  }
-
   /**
    * Returns <code>null</code>.
    * @since 5.2
