@@ -50,11 +50,12 @@ public class HomePieceOfFurniture extends HomeObject implements PieceOfFurniture
    * The properties of a piece of furniture that may change. <code>PropertyChangeListener</code>s added
    * to a piece of furniture will be notified under a property name equal to the string value of one these properties.
    */
-  public enum Property {NAME, NAME_VISIBLE, NAME_X_OFFSET, NAME_Y_OFFSET, NAME_STYLE, NAME_ANGLE,
-      DESCRIPTION, PRICE, VALUE_ADDED_TAX_PERCENTAGE, CURRENCY,
+  public enum Property {CATALOG_ID, NAME, NAME_VISIBLE, NAME_X_OFFSET, NAME_Y_OFFSET, NAME_STYLE, NAME_ANGLE,
+      DESCRIPTION, INFORMATION, PRICE, VALUE_ADDED_TAX_PERCENTAGE, CURRENCY, ICON, PLAN_ICON, MODEL,
       WIDTH, WIDTH_IN_PLAN, DEPTH, DEPTH_IN_PLAN, HEIGHT, HEIGHT_IN_PLAN,
-      COLOR, TEXTURE, MODEL_MATERIALS, SHININESS, VISIBLE, MODEL_TRANSFORMATIONS,
-      X, Y, ELEVATION, ANGLE, PITCH, ROLL, MODEL_MIRRORED, MOVABLE, LEVEL};
+      COLOR, TEXTURE, MODEL_MATERIALS, MODEL_TRANSFORMATIONS,
+      STAIRCASE_CUT_OUT_SHAPE, CREATOR, SHININESS, VISIBLE,
+      X, Y, ELEVATION, ANGLE, PITCH, ROLL, MODEL_ROTATION, MODEL_MIRRORED, BACK_FACE_SHOWN, MOVABLE, LEVEL};
 
   /**
    * The properties on which home furniture may be sorted.
@@ -63,7 +64,6 @@ public class HomePieceOfFurniture extends HomeObject implements PieceOfFurniture
                                 DOOR_OR_WINDOW, COLOR, TEXTURE, VISIBLE, X, Y, ELEVATION, ANGLE, MODEL_SIZE, CREATOR,
                                 PRICE, VALUE_ADDED_TAX, VALUE_ADDED_TAX_PERCENTAGE, PRICE_VALUE_ADDED_TAX_INCLUDED, LEVEL};
   private static final Map<SortableProperty, Comparator<HomePieceOfFurniture>> SORTABLE_PROPERTY_COMPARATORS;
-  private static final float [][] IDENTITY = new float [][] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}};
 
   static {
     final Collator collator = Collator.getInstance();
@@ -416,7 +416,7 @@ public class HomePieceOfFurniture extends HomeObject implements PieceOfFurniture
    */
   private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException {
     this.dropOnTopElevation = 1f;
-    this.modelRotation = IDENTITY;
+    this.modelRotation = IDENTITY_ROTATION;
     this.resizable = true;
     this.deformable = true;
     this.texturable = true;
@@ -440,7 +440,7 @@ public class HomePieceOfFurniture extends HomeObject implements PieceOfFurniture
     }
     if (!this.modelCenteredAtOrigin) {
       // Keep default value to false only if model rotation matrix isn't identity
-      this.modelCenteredAtOrigin = Arrays.deepEquals(IDENTITY, this.modelRotation);
+      this.modelCenteredAtOrigin = Arrays.deepEquals(IDENTITY_ROTATION, this.modelRotation);
     }
   }
 
@@ -451,6 +451,20 @@ public class HomePieceOfFurniture extends HomeObject implements PieceOfFurniture
     return this.catalogId;
   }
 
+  /**
+   * Sets the catalog ID of this piece of furniture. Once this piece is updated,
+   * listeners added to this piece will receive a change notification.
+   * @since 6.5
+   */
+  public void setCatalogId(String catalogId) {
+    if (catalogId != this.catalogId
+        && (catalogId == null || !catalogId.equals(this.catalogId))) {
+      String oldCatalogId = this.catalogId;
+      this.catalogId = catalogId;
+      firePropertyChange(Property.CATALOG_ID.name(), oldCatalogId, catalogId);
+    }
+  }
+
   /**
    * Returns the name of this piece of furniture.
    */
@@ -599,6 +613,20 @@ public class HomePieceOfFurniture extends HomeObject implements PieceOfFurniture
     return this.information;
   }
 
+  /**
+   * Sets the additional information associated to this piece . Once this piece is updated,
+   * listeners added to this piece will receive a change notification.
+   * @since 6.5
+   */
+  public void setInformation(String information) {
+    if (information != this.information
+        && (information == null || !information.equals(this.information))) {
+      String oldInformation = this.information;
+      this.information = information;
+      firePropertyChange(Property.INFORMATION.name(), oldInformation, information);
+    }
+  }
+
   /**
    * Returns the depth of this piece of furniture.
    */
@@ -826,6 +854,20 @@ public class HomePieceOfFurniture extends HomeObject implements PieceOfFurniture
     return this.icon;
   }
 
+  /**
+   * Sets the icon of this piece of furniture. Once this piece is updated,
+   * listeners added to this piece will receive a change notification.
+   * @since 6.5
+   */
+  public void setIcon(Content icon) {
+    if (icon != this.icon
+        && (icon == null || !icon.equals(this.icon))) {
+      Content oldIcon = this.icon;
+      this.icon = icon;
+      firePropertyChange(Property.ICON.name(), oldIcon, icon);
+    }
+  }
+
   /**
    * Returns the icon of this piece of furniture displayed in plan or <code>null</code>.
    * @since 2.2
@@ -834,6 +876,20 @@ public class HomePieceOfFurniture extends HomeObject implements PieceOfFurniture
     return this.planIcon;
   }
 
+  /**
+   * Sets the plan icon of this piece of furniture. Once this piece is updated,
+   * listeners added to this piece will receive a change notification.
+   * @since 6.5
+   */
+  public void setPlanIcon(Content planIcon) {
+    if (planIcon != this.planIcon
+        && (planIcon == null || !planIcon.equals(this.planIcon))) {
+      Content oldPlanIcon = this.planIcon;
+      this.planIcon = planIcon;
+      firePropertyChange(Property.PLAN_ICON.name(), oldPlanIcon, planIcon);
+    }
+  }
+
   /**
    * Returns the 3D model of this piece of furniture.
    */
@@ -841,6 +897,28 @@ public class HomePieceOfFurniture extends HomeObject implements PieceOfFurniture
     return this.model;
   }
 
+  /**
+   * Sets the 3D model of this piece of furniture. Once this piece is updated,
+   * listeners added to this piece will receive a change notification.
+   * @since 6.5
+   */
+  public void setModel(Content model) {
+    if (model != this.model
+        && (model == null || !model.equals(this.model))) {
+      Content oldModel = this.model;
+      this.model = model;
+      firePropertyChange(Property.MODEL.name(), oldModel, model);
+    }
+  }
+
+  /**
+   * Returns the size of the 3D model of this piece of furniture.
+   * @since 5.5
+   */
+  public Long getModelSize() {
+    return this.modelSize;
+  }
+
   /**
    * Sets the size of the 3D model of this piece of furniture.
    * This method should be called only to update a piece created with an older version.
@@ -851,11 +929,17 @@ public class HomePieceOfFurniture extends HomeObject implements PieceOfFurniture
   }
 
   /**
-   * Returns the size of the 3D model of this piece of furniture.
-   * @since 5.5
+   * Returns the materials applied to the 3D model of this piece of furniture.
+   * @return the materials of the 3D model or <code>null</code>
+   * if the individual materials of the 3D model are not modified.
+   * @since 4.0
    */
-  public Long getModelSize() {
-    return this.modelSize;
+  public HomeMaterial [] getModelMaterials() {
+    if (this.modelMaterials != null) {
+      return this.modelMaterials.clone();
+    } else {
+      return null;
+    }
   }
 
   /**
@@ -879,20 +963,6 @@ public class HomePieceOfFurniture extends HomeObject implements PieceOfFurniture
     }
   }
 
-  /**
-   * Returns the materials applied to the 3D model of this piece of furniture.
-   * @return the materials of the 3D model or <code>null</code>
-   * if the individual materials of the 3D model are not modified.
-   * @since 4.0
-   */
-  public HomeMaterial [] getModelMaterials() {
-    if (this.modelMaterials != null) {
-      return this.modelMaterials.clone();
-    } else {
-      return null;
-    }
-  }
-
   /**
    * Returns the color of this piece of furniture.
    * @return the color of the piece as RGB code or <code>null</code> if piece color is unchanged.
@@ -1248,6 +1318,27 @@ public class HomePieceOfFurniture extends HomeObject implements PieceOfFurniture
     return this.roll != 0 || this.pitch != 0;
   }
 
+  /**
+   * Returns the rotation 3 by 3 matrix of this piece of furniture that ensures
+   * its model is correctly oriented.
+   */
+  public float [][] getModelRotation() {
+    // Return a deep copy to avoid any misuse of piece data
+    return CatalogPieceOfFurniture.deepClone(this.modelRotation);
+  }
+
+  /**
+   * Sets the rotation 3 by 3 matrix of this piece of furniture and notifies listeners of this change.
+   * @since 6.5
+   */
+  public void setModelRotation(float [][] modelRotation) {
+    if (!Arrays.deepEquals(modelRotation, this.modelRotation)) {
+      float [][] oldModelRotation = CatalogPieceOfFurniture.deepClone(this.modelRotation);
+      this.modelRotation = CatalogPieceOfFurniture.deepClone(modelRotation);
+      firePropertyChange(Property.MODEL_ROTATION.name(), oldModelRotation, modelRotation);
+    }
+  }
+
   /**
    * Returns <code>true</code> if the model of this piece should be mirrored.
    */
@@ -1273,14 +1364,13 @@ public class HomePieceOfFurniture extends HomeObject implements PieceOfFurniture
   }
 
   /**
-   * Returns the rotation 3 by 3 matrix of this piece of furniture that ensures
-   * its model is correctly oriented.
+   * Returns <code>true</code> if model center should be always centered at the origin
+   * when model rotation isn't <code>null</code>.
+   * @return <code>false</code> by default if version < 5.5
+   * @since 5.5
    */
-  public float [][] getModelRotation() {
-    // Return a deep copy to avoid any misuse of piece data
-    return new float [][] {{this.modelRotation[0][0], this.modelRotation[0][1], this.modelRotation[0][2]},
-                           {this.modelRotation[1][0], this.modelRotation[1][1], this.modelRotation[1][2]},
-                           {this.modelRotation[2][0], this.modelRotation[2][1], this.modelRotation[2][2]}};
+  public boolean isModelCenteredAtOrigin() {
+    return this.modelCenteredAtOrigin;
   }
 
   /**
@@ -1294,16 +1384,39 @@ public class HomePieceOfFurniture extends HomeObject implements PieceOfFurniture
     this.modelCenteredAtOrigin = modelCenteredAtOrigin;
   }
 
-
+  /**
+   * Returns <code>true</code> if the back face of the piece of furniture
+   * model should be displayed.
+   */
+  public boolean isBackFaceShown() {
+    return this.backFaceShown;
+  }
 
   /**
-   * Returns <code>true</code> if model center should be always centered at the origin
-   * when model rotation isn't <code>null</code>.
-   * @return <code>false</code> by default if version < 5.5
-   * @since 5.5
+   * Sets whether the back face of the piece of furniture model should be displayed.
+   * Once this piece is updated, listeners added to this piece will receive a change notification.
+   * @since 6.5
    */
-  public boolean isModelCenteredAtOrigin() {
-    return this.modelCenteredAtOrigin;
+  public void setBackFaceShown(boolean backFaceShown) {
+    if (backFaceShown != this.backFaceShown) {
+      this.backFaceShown = backFaceShown;
+      firePropertyChange(Property.BACK_FACE_SHOWN.name(),
+          !backFaceShown, backFaceShown);
+    }
+  }
+
+  /**
+   * Returns the transformations applied to the 3D model of this piece of furniture.
+   * @return the transformations of the 3D model or <code>null</code>
+   * if the 3D model is not transformed.
+   * @since 6.0
+   */
+  public Transformation [] getModelTransformations() {
+    if (this.modelTransformations != null) {
+      return this.modelTransformations.clone();
+    } else {
+      return null;
+    }
   }
 
   /**
@@ -1322,20 +1435,6 @@ public class HomePieceOfFurniture extends HomeObject implements PieceOfFurniture
      }
   }
 
-  /**
-   * Returns the transformations applied to the 3D model of this piece of furniture.
-   * @return the transformations of the 3D model or <code>null</code>
-   * if the 3D model is not transformed.
-   * @since 6.0
-   */
-  public Transformation [] getModelTransformations() {
-    if (this.modelTransformations != null) {
-      return this.modelTransformations.clone();
-    } else {
-      return null;
-    }
-  }
-
   /**
    * Returns the shape used to cut out upper levels when they intersect with the piece
    * like a staircase.
@@ -1345,6 +1444,21 @@ public class HomePieceOfFurniture extends HomeObject implements PieceOfFurniture
     return this.staircaseCutOutShape;
   }
 
+  /**
+   * Sets the shape used to cut out upper levels when they intersect with the piece
+   * like a staircase. Once this piece is updated, listeners added to this piece
+   * will receive a change notification.
+   * @since 6.5
+   */
+  public void setStaircaseCutOutShape(String staircaseCutOutShape) {
+    if (staircaseCutOutShape != this.staircaseCutOutShape
+        && (staircaseCutOutShape == null || !staircaseCutOutShape.equals(this.staircaseCutOutShape))) {
+      String oldCutOutShape = this.staircaseCutOutShape;
+      this.staircaseCutOutShape = staircaseCutOutShape;
+      firePropertyChange(Property.STAIRCASE_CUT_OUT_SHAPE.name(), oldCutOutShape, staircaseCutOutShape);
+    }
+  }
+
   /**
    * Returns the creator of this piece.
    * @since 4.2
@@ -1354,11 +1468,17 @@ public class HomePieceOfFurniture extends HomeObject implements PieceOfFurniture
   }
 
   /**
-   * Returns <code>true</code> if the back face of the piece of furniture
-   * model should be displayed.
+   * Sets the creator of this piece. Once this piece is updated, listeners added to this piece
+   * will receive a change notification.
+   * @since 6.5
    */
-  public boolean isBackFaceShown() {
-    return this.backFaceShown;
+  public void setCreator(String creator) {
+    if (creator != this.creator
+        && (creator == null || !creator.equals(this.creator))) {
+      String oldCreator = this.creator;
+      this.creator = creator;
+      firePropertyChange(Property.CREATOR.name(), oldCreator, creator);
+    }
   }
 
   /**
