@@ -24,10 +24,6 @@ import java.awt.geom.GeneralPath;
 import java.awt.geom.Line2D;
 import java.awt.geom.Point2D;
 import java.awt.geom.Rectangle2D;
-import java.beans.PropertyChangeListener;
-import java.beans.PropertyChangeSupport;
-import java.io.IOException;
-import java.io.ObjectInputStream;
 import java.util.ArrayList;
 import java.util.List;
 
@@ -71,7 +67,6 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
   private Integer             topColor;
   private Level               level;
 
-  private transient PropertyChangeSupport propertyChangeSupport = new PropertyChangeSupport(this);
   private transient Shape      shapeCache;
   private transient float []   arcCircleCenterCache;
   private transient float [][] pointsCache;
@@ -97,6 +92,16 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
     this(xStart, yStart, xEnd, yEnd, thickness, height, null);
   }
 
+ /**
+   * Creates a wall from (<code>xStart</code>,<code>yStart</code>)
+   * to (<code>xEnd</code>, <code>yEnd</code>),
+   * with given thickness and height. Pattern, left and right colors are <code>null</code>.
+   * @since 6.4
+   */
+  public Wall(String id, float xStart, float yStart, float xEnd, float yEnd, float thickness, float height) {
+    this(id, xStart, yStart, xEnd, yEnd, thickness, height, null);
+  }
+
   /**
    * Creates a wall from (<code>xStart</code>,<code>yStart</code>)
    * to (<code>xEnd</code>, <code>yEnd</code>),
@@ -105,6 +110,18 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
    * @since 4.0
    */
   public Wall(float xStart, float yStart, float xEnd, float yEnd, float thickness, float height, TextureImage pattern) {
+    this(createId("wall"), xStart, yStart, xEnd, yEnd, thickness, height, pattern);
+  }
+
+  /**
+   * Creates a wall from (<code>xStart</code>,<code>yStart</code>)
+   * to (<code>xEnd</code>, <code>yEnd</code>),
+   * with given thickness, height and pattern.
+   * Colors are <code>null</code>.
+   * @since 6.4
+   */
+  public Wall(String id, float xStart, float yStart, float xEnd, float yEnd, float thickness, float height, TextureImage pattern) {
+    super(id);
     this.xStart = xStart;
     this.yStart = yStart;
     this.xEnd = xEnd;
@@ -114,29 +131,6 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
     this.pattern = pattern;
   }
 
-  /**
-   * Initializes new wall transient fields
-   * and reads wall from <code>in</code> stream with default reading method.
-   */
-  private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException {
-    this.propertyChangeSupport = new PropertyChangeSupport(this);
-    in.defaultReadObject();
-  }
-
-  /**
-   * Adds the property change <code>listener</code> in parameter to this wall.
-   */
-  public void addPropertyChangeListener(PropertyChangeListener listener) {
-    this.propertyChangeSupport.addPropertyChangeListener(listener);
-  }
-
-  /**
-   * Removes the property change <code>listener</code> in parameter from this wall.
-   */
-  public void removePropertyChangeListener(PropertyChangeListener listener) {
-    this.propertyChangeSupport.removePropertyChangeListener(listener);
-  }
-
   /**
    * Returns the start point abscissa of this wall.
    */
@@ -154,7 +148,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
       this.xStart = xStart;
       clearPointsCache();
       this.arcCircleCenterCache = null;
-      this.propertyChangeSupport.firePropertyChange(Property.X_START.name(), oldXStart, xStart);
+      firePropertyChange(Property.X_START.name(), oldXStart, xStart);
     }
   }
 
@@ -175,7 +169,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
       this.yStart = yStart;
       clearPointsCache();
       this.arcCircleCenterCache = null;
-      this.propertyChangeSupport.firePropertyChange(Property.Y_START.name(), oldYStart, yStart);
+      firePropertyChange(Property.Y_START.name(), oldYStart, yStart);
     }
   }
 
@@ -196,7 +190,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
       this.xEnd = xEnd;
       clearPointsCache();
       this.arcCircleCenterCache = null;
-      this.propertyChangeSupport.firePropertyChange(Property.X_END.name(), oldXEnd, xEnd);
+      firePropertyChange(Property.X_END.name(), oldXEnd, xEnd);
     }
   }
 
@@ -217,7 +211,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
       this.yEnd = yEnd;
       clearPointsCache();
       this.arcCircleCenterCache = null;
-      this.propertyChangeSupport.firePropertyChange(Property.Y_END.name(), oldYEnd, yEnd);
+      firePropertyChange(Property.Y_END.name(), oldYEnd, yEnd);
     }
   }
 
@@ -256,8 +250,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
       this.arcExtent = arcExtent;
       clearPointsCache();
       this.arcCircleCenterCache = null;
-      this.propertyChangeSupport.firePropertyChange(Property.ARC_EXTENT.name(),
-          oldArcExtent, arcExtent);
+      firePropertyChange(Property.ARC_EXTENT.name(), oldArcExtent, arcExtent);
     }
   }
 
@@ -344,8 +337,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
       Wall oldWallAtStart = this.wallAtStart;
       this.wallAtStart = wallAtStart;
       clearPointsCache();
-      this.propertyChangeSupport.firePropertyChange(Property.WALL_AT_START.name(),
-          oldWallAtStart, wallAtStart);
+      firePropertyChange(Property.WALL_AT_START.name(), oldWallAtStart, wallAtStart);
 
       if (detachJoinedWallAtStart) {
         detachJoinedWall(oldWallAtStart);
@@ -382,8 +374,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
       Wall oldWallAtEnd = this.wallAtEnd;
       this.wallAtEnd = wallAtEnd;
       clearPointsCache();
-      this.propertyChangeSupport.firePropertyChange(Property.WALL_AT_END.name(),
-          oldWallAtEnd, wallAtEnd);
+      firePropertyChange(Property.WALL_AT_END.name(), oldWallAtEnd, wallAtEnd);
 
       if (detachJoinedWallAtEnd) {
         detachJoinedWall(oldWallAtEnd);
@@ -421,8 +412,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
       float oldThickness = this.thickness;
       this.thickness = thickness;
       clearPointsCache();
-      this.propertyChangeSupport.firePropertyChange(Property.THICKNESS.name(),
-          oldThickness, thickness);
+      firePropertyChange(Property.THICKNESS.name(), oldThickness, thickness);
     }
   }
 
@@ -444,8 +434,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
         && (height == null || !height.equals(this.height))) {
       Float oldHeight = this.height;
       this.height = height;
-      this.propertyChangeSupport.firePropertyChange(Property.HEIGHT.name(),
-          oldHeight, height);
+      firePropertyChange(Property.HEIGHT.name(), oldHeight, height);
     }
   }
 
@@ -465,8 +454,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
         && (heightAtEnd == null || !heightAtEnd.equals(this.heightAtEnd))) {
       Float oldHeightAtEnd = this.heightAtEnd;
       this.heightAtEnd = heightAtEnd;
-      this.propertyChangeSupport.firePropertyChange(Property.HEIGHT_AT_END.name(),
-          oldHeightAtEnd, heightAtEnd);
+      firePropertyChange(Property.HEIGHT_AT_END.name(), oldHeightAtEnd, heightAtEnd);
     }
   }
 
@@ -497,8 +485,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
         && (leftSideColor == null || !leftSideColor.equals(this.leftSideColor))) {
       Integer oldLeftSideColor = this.leftSideColor;
       this.leftSideColor = leftSideColor;
-      this.propertyChangeSupport.firePropertyChange(Property.LEFT_SIDE_COLOR.name(),
-          oldLeftSideColor, leftSideColor);
+      firePropertyChange(Property.LEFT_SIDE_COLOR.name(), oldLeftSideColor, leftSideColor);
     }
   }
 
@@ -519,8 +506,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
         && (rightSideColor == null || !rightSideColor.equals(this.rightSideColor))) {
       Integer oldLeftSideColor = this.rightSideColor;
       this.rightSideColor = rightSideColor;
-      this.propertyChangeSupport.firePropertyChange(Property.RIGHT_SIDE_COLOR.name(),
-          oldLeftSideColor, rightSideColor);
+      firePropertyChange(Property.RIGHT_SIDE_COLOR.name(), oldLeftSideColor, rightSideColor);
     }
   }
 
@@ -541,8 +527,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
         && (leftSideTexture == null || !leftSideTexture.equals(this.leftSideTexture))) {
       HomeTexture oldLeftSideTexture = this.leftSideTexture;
       this.leftSideTexture = leftSideTexture;
-      this.propertyChangeSupport.firePropertyChange(Property.LEFT_SIDE_TEXTURE.name(),
-          oldLeftSideTexture, leftSideTexture);
+      firePropertyChange(Property.LEFT_SIDE_TEXTURE.name(), oldLeftSideTexture, leftSideTexture);
     }
   }
 
@@ -562,8 +547,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
         && (rightSideTexture == null || !rightSideTexture.equals(this.rightSideTexture))) {
       HomeTexture oldLeftSideTexture = this.rightSideTexture;
       this.rightSideTexture = rightSideTexture;
-      this.propertyChangeSupport.firePropertyChange(Property.RIGHT_SIDE_TEXTURE.name(),
-          oldLeftSideTexture, rightSideTexture);
+      firePropertyChange(Property.RIGHT_SIDE_TEXTURE.name(), oldLeftSideTexture, rightSideTexture);
     }
   }
 
@@ -585,7 +569,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
     if (leftSideShininess != this.leftSideShininess) {
       float oldLeftSideShininess = this.leftSideShininess;
       this.leftSideShininess = leftSideShininess;
-      this.propertyChangeSupport.firePropertyChange(Property.LEFT_SIDE_SHININESS.name(), oldLeftSideShininess, leftSideShininess);
+      firePropertyChange(Property.LEFT_SIDE_SHININESS.name(), oldLeftSideShininess, leftSideShininess);
     }
   }
 
@@ -607,7 +591,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
     if (rightSideShininess != this.rightSideShininess) {
       float oldRightSideShininess = this.rightSideShininess;
       this.rightSideShininess = rightSideShininess;
-      this.propertyChangeSupport.firePropertyChange(Property.RIGHT_SIDE_SHININESS.name(), oldRightSideShininess, rightSideShininess);
+      firePropertyChange(Property.RIGHT_SIDE_SHININESS.name(), oldRightSideShininess, rightSideShininess);
     }
   }
 
@@ -630,7 +614,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
       Baseboard oldLeftSideBaseboard = this.leftSideBaseboard;
       this.leftSideBaseboard = leftSideBaseboard;
       clearPointsCache();
-      this.propertyChangeSupport.firePropertyChange(Property.LEFT_SIDE_BASEBOARD.name(), oldLeftSideBaseboard, leftSideBaseboard);
+      firePropertyChange(Property.LEFT_SIDE_BASEBOARD.name(), oldLeftSideBaseboard, leftSideBaseboard);
     }
   }
 
@@ -653,7 +637,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
       Baseboard oldRightSideBaseboard = this.rightSideBaseboard;
       this.rightSideBaseboard = rightSideBaseboard;
       clearPointsCache();
-      this.propertyChangeSupport.firePropertyChange(Property.RIGHT_SIDE_BASEBOARD.name(), oldRightSideBaseboard, rightSideBaseboard);
+      firePropertyChange(Property.RIGHT_SIDE_BASEBOARD.name(), oldRightSideBaseboard, rightSideBaseboard);
     }
   }
 
@@ -674,8 +658,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
     if (this.pattern != pattern) {
       TextureImage oldPattern = this.pattern;
       this.pattern = pattern;
-      this.propertyChangeSupport.firePropertyChange(Property.PATTERN.name(),
-          oldPattern, pattern);
+      firePropertyChange(Property.PATTERN.name(), oldPattern, pattern);
     }
   }
 
@@ -697,8 +680,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
         && (topColor == null || !topColor.equals(this.topColor))) {
       Integer oldTopColor = this.topColor;
       this.topColor = topColor;
-      this.propertyChangeSupport.firePropertyChange(Property.TOP_COLOR.name(),
-          oldTopColor, topColor);
+      firePropertyChange(Property.TOP_COLOR.name(), oldTopColor, topColor);
     }
   }
 
@@ -719,7 +701,7 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
     if (level != this.level) {
       Level oldLevel = this.level;
       this.level = level;
-      this.propertyChangeSupport.firePropertyChange(Property.LEVEL.name(), oldLevel, level);
+      firePropertyChange(Property.LEVEL.name(), oldLevel, level);
     }
   }
 
@@ -1196,6 +1178,33 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
     return this.shapeCache;
   }
 
+  /**
+   * Moves this wall of (<code>dx</code>, <code>dy</code>) units.
+   */
+  public void move(float dx, float dy) {
+    setXStart(getXStart() + dx);
+    setYStart(getYStart() + dy);
+    setXEnd(getXEnd() + dx);
+    setYEnd(getYEnd() + dy);
+  }
+
+  /**
+   * Returns a duplicate of the <code>walls</code> list. All existing walls
+   * are copied and their wall at start and end point are set with copied
+   * walls only if they belong to the returned list.
+   * The id of duplicated walls are regenerated.
+   * @since 6.4
+   */
+  public static List<Wall> duplicate(List<Wall> walls) {
+    ArrayList<Wall> wallsCopy = new ArrayList<Wall>(walls.size());
+    // Duplicate walls
+    for (Wall wall : walls) {
+      wallsCopy.add((Wall)wall.duplicate());
+    }
+    updateBoundWalls(wallsCopy, walls);
+    return wallsCopy;
+  }
+
   /**
    * Returns a clone of the <code>walls</code> list. All existing walls
    * are copied and their wall at start and end point are set with copied
@@ -1207,7 +1216,12 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
     for (Wall wall : walls) {
       wallsCopy.add(wall.clone());
     }
-    // Update walls at start and end point
+    updateBoundWalls(wallsCopy, walls);
+    return wallsCopy;
+  }
+
+  private static void updateBoundWalls(ArrayList<Wall> wallsCopy, List<Wall> walls) {
+    // Update walls at start and end point in wallsCopy
     for (int i = 0; i < walls.size(); i++) {
       Wall wall = walls.get(i);
       int wallAtStartIndex = walls.indexOf(wall.getWallAtStart());
@@ -1219,17 +1233,6 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
         wallsCopy.get(i).setWallAtEnd(wallsCopy.get(wallAtEndIndex));
       }
     }
-    return wallsCopy;
-  }
-
-  /**
-   * Moves this wall of (<code>dx</code>, <code>dy</code>) units.
-   */
-  public void move(float dx, float dy) {
-    setXStart(getXStart() + dx);
-    setYStart(getYStart() + dy);
-    setXEnd(getXEnd() + dx);
-    setYEnd(getYEnd() + dy);
   }
 
   /**
@@ -1239,7 +1242,6 @@ public class Wall extends HomeObject implements Selectable, Elevatable {
   @Override
   public Wall clone() {
     Wall clone = (Wall)super.clone();
-    clone.propertyChangeSupport = new PropertyChangeSupport(clone);
     clone.wallAtStart = null;
     clone.wallAtEnd = null;
     clone.level = null;
