@@ -35,6 +35,7 @@ import java.awt.GraphicsEnvironment;
 import java.awt.GridBagLayout;
 import java.awt.Image;
 import java.awt.Insets;
+import java.awt.KeyboardFocusManager;
 import java.awt.MouseInfo;
 import java.awt.Point;
 import java.awt.Rectangle;
@@ -57,6 +58,7 @@ import java.awt.image.FilteredImageSource;
 import java.awt.image.RGBImageFilter;
 import java.io.IOException;
 import java.io.InputStream;
+import java.net.MalformedURLException;
 import java.net.URL;
 import java.security.AccessControlException;
 import java.util.ArrayList;
@@ -67,6 +69,7 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
+import java.util.Map.Entry;
 import java.util.MissingResourceException;
 import java.util.ResourceBundle;
 import java.util.concurrent.Executors;
@@ -95,6 +98,7 @@ import javax.swing.JSeparator;
 import javax.swing.JToggleButton;
 import javax.swing.JToolTip;
 import javax.swing.JViewport;
+import javax.swing.RootPaneContainer;
 import javax.swing.SwingUtilities;
 import javax.swing.Timer;
 import javax.swing.ToolTipManager;
@@ -455,32 +459,138 @@ public class SwingTools {
                                       JComponent messageComponent,
                                       String title,
                                       final JComponent focusedComponent) {
-    JOptionPane optionPane = new JOptionPane(messageComponent,
-        JOptionPane.PLAIN_MESSAGE, JOptionPane.OK_CANCEL_OPTION);
-    parentComponent = SwingUtilities.getRootPane(parentComponent);
-    final JDialog dialog = optionPane.createDialog(parentComponent, title);
-    dialog.applyComponentOrientation(parentComponent != null
-        ? parentComponent.getComponentOrientation()
-        : ComponentOrientation.getOrientation(Locale.getDefault()));
-    if (focusedComponent != null) {
-      // Add a listener that transfer focus to focusedComponent when dialog is shown
-      dialog.addComponentListener(new ComponentAdapter() {
-          @Override
-          public void componentShown(ComponentEvent ev) {
-            requestFocusInWindow(focusedComponent);
-            dialog.removeComponentListener(this);
-          }
-        });
-    }
-    dialog.setVisible(true);
+    return showOptionDialog(parentComponent, messageComponent, title,
+        JOptionPane.OK_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, null, null, focusedComponent);
+  }
 
-    dialog.dispose();
-    Object value = optionPane.getValue();
-    if (value instanceof Integer) {
-      return (Integer)value;
-    } else {
-      return JOptionPane.CLOSED_OPTION;
+  /**
+   * Displays <code>message</code> in a modal dialog box.
+   */
+  public static void showMessageDialog(JComponent parentComponent,
+                                       Object message,
+                                       String title,
+                                       int messageType) {
+    showOptionDialog(parentComponent, message, title, JOptionPane.DEFAULT_OPTION, messageType, null, null, null);
+  }
+
+  /**
+   * Displays <code>messageComponent</code> in a modal dialog box, giving focus to one of its components.
+   */
+  public static void showMessageDialog(JComponent parentComponent,
+                                       JComponent messageComponent,
+                                       String title,
+                                       int messageType,
+                                       final JComponent focusedComponent) {
+    showOptionDialog(parentComponent, messageComponent, title, JOptionPane.DEFAULT_OPTION, messageType, null, null, focusedComponent);
+  }
+
+  /**
+   * Displays message in a dialog box, possibly adjusting font size if required.
+   */
+  public static int showOptionDialog(Component parentComponent,
+                                     String message, String title,
+                                     int optionType, int messageType,
+                                     Object[] options, Object initialValue) {
+    if (SwingTools.getResolutionScale() > 1
+        && message.indexOf("<font size=\"-2\">") != -1) {
+      Font font = UIManager.getFont("OptionPane.font");
+      if (font != null) {
+        message = message.replace("<font size=\"-2\">", "<font size=\"" + Math.round(font.getSize() / 5f) + "\">");
+      }
     }
+    return showOptionDialog(parentComponent, message, title, optionType, messageType, options, initialValue, null);
+  }
+
+  /**
+   * Displays message in a dialog box.
+   */
+  private static int showOptionDialog(Component parentComponent,
+                                      Object message, String title,
+                                      int optionType, int messageType,
+                                      Object[] options, Object initialValue,
+                                      final JComponent focusedComponent) {
+   JOptionPane optionPane = new JOptionPane(message,
+       messageType, optionType, null, options, initialValue);
+   parentComponent = getDialogParent(parentComponent);
+   final JDialog dialog = optionPane.createDialog(parentComponent, title);
+   dialog.applyComponentOrientation(parentComponent != null
+       ? parentComponent.getComponentOrientation()
+       : ComponentOrientation.getOrientation(Locale.getDefault()));
+   if (focusedComponent != null) {
+     // Add a listener that transfer focus to focusedComponent when dialog is shown
+     dialog.addComponentListener(new ComponentAdapter() {
+         @Override
+         public void componentShown(ComponentEvent ev) {
+           requestFocusInWindow(focusedComponent);
+           dialog.removeComponentListener(this);
+         }
+       });
+   }
+
+   Map<JDialog, Rectangle> childDialogBounds = new HashMap<JDialog, Rectangle>();
+   if (OperatingSystem.isMacOSX()
+       && OperatingSystem.isJavaVersionGreaterOrEqual("1.7")) {
+     // Move not modal dialogs away to ensure the option pane dialog won't be hidden by them
+     Rectangle optionPaneDialogBounds = dialog.getBounds();
+     Window parentWindow = (Window)dialog.getParent();
+     for (Window childWindow : parentWindow.getOwnedWindows()) {
+       if (dialog != childWindow) {
+         if (childWindow instanceof JDialog
+             && childWindow.isVisible()
+             && !((JDialog)childWindow).isModal()) {
+           Rectangle bounds = childWindow.getBounds();
+           if (bounds.intersects(optionPaneDialogBounds)) {
+             childWindow.setLocation(optionPaneDialogBounds.x + optionPaneDialogBounds.width + 10, bounds.y);
+             childDialogBounds.put((JDialog)childWindow, bounds);
+           }
+         }
+       }
+     }
+   }
+
+   try {
+     dialog.setVisible(true);
+   } finally {
+     // Restore location of moved dialogs
+     for (Entry<JDialog, Rectangle> childDialogEntry : childDialogBounds.entrySet()) {
+       childDialogEntry.getKey().setBounds(childDialogEntry.getValue());
+     }
+   }
+
+   dialog.dispose();
+   Object value = optionPane.getValue();
+   if (value != null) {
+     if (options != null) {
+       for (int i = 0; i < options.length; i++) {
+          if (value.equals(options [i])) {
+            return i;
+          }
+        }
+      } else {
+        if (value instanceof Integer) {
+          return (Integer)value;
+        }
+      }
+    }
+    return JOptionPane.CLOSED_OPTION;
+  }
+
+  /**
+   * Returns the parent of the given component which may be used as dialog parent.
+   */
+  private static JComponent getDialogParent(Component component) {
+    JComponent parentComponent = SwingUtilities.getRootPane(component);
+    if (OperatingSystem.isMacOSX()) {
+      if (parentComponent == null
+          || SwingUtilities.getWindowAncestor(parentComponent) == null) {
+        // Use active window if possible to ensure the dialog will be displayed in front of current window
+        Window activeWindow = KeyboardFocusManager.getCurrentKeyboardFocusManager().getActiveWindow();
+        if (activeWindow instanceof RootPaneContainer) {
+          parentComponent = ((RootPaneContainer)activeWindow).getRootPane();
+        }
+      }
+    }
+    return parentComponent;
   }
 
   /**
@@ -499,52 +609,6 @@ public class SwingTools {
     }
   }
 
-  /**
-   * Displays <code>messageComponent</code> in a modal dialog box, giving focus to one of its components.
-   */
-  public static void showMessageDialog(JComponent parentComponent,
-                                       JComponent messageComponent,
-                                       String title,
-                                       int messageType,
-                                       final JComponent focusedComponent) {
-    JOptionPane optionPane = new JOptionPane(messageComponent, messageType, JOptionPane.DEFAULT_OPTION);
-    parentComponent = SwingUtilities.getRootPane(parentComponent);
-    final JDialog dialog = optionPane.createDialog(parentComponent, title);
-    dialog.applyComponentOrientation(parentComponent != null
-        ? parentComponent.getComponentOrientation()
-        : ComponentOrientation.getOrientation(Locale.getDefault()));
-    if (focusedComponent != null) {
-      // Add a listener that transfer focus to focusedComponent when dialog is shown
-      dialog.addComponentListener(new ComponentAdapter() {
-          @Override
-          public void componentShown(ComponentEvent ev) {
-            requestFocusInWindow(focusedComponent);
-            dialog.removeComponentListener(this);
-          }
-        });
-    }
-    dialog.setVisible(true);
-    dialog.dispose();
-  }
-
-  /**
-   * Displays message in a dialog box, possibly adjusting font size if required.
-   */
-  public static int showOptionDialog(Component parentComponent,
-                                     String message, String title,
-                                     int optionType, int messageType,
-                                     Object[] options, Object initialValue) {
-   if (SwingTools.getResolutionScale() > 1
-       && message.indexOf("<font size=\"-2\">") != -1) {
-     Font font = UIManager.getFont("OptionPane.font");
-     if (font != null) {
-       message = message.replace("<font size=\"-2\">", "<font size=\"" + Math.round(font.getSize() / 5f) + "\">");
-     }
-   }
-   return JOptionPane.showOptionDialog(parentComponent, message, title, optionType,
-       messageType, null, options, initialValue);
- }
-
   private static Map<TextureImage, BufferedImage> patternImages;
 
   /**
@@ -612,68 +676,64 @@ public class SwingTools {
    * If the <code>imageUrl</code> is incorrect, nothing happens.
    */
   public static void showSplashScreenWindow(URL imageUrl) {
-    try {
-      final BufferedImage image = ImageIO.read(imageUrl);
-      // Try to find an image scale without getResolutionScale()
-      // because look and feel is probably not set yet
-      Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
-      final float scale = OperatingSystem.isMacOSX()
-          ? 1f
-          : (float)Math.min(2, Math.max(1, Math.min(screenSize.getWidth() / 5 / image.getWidth(), screenSize.getHeight() / 5 / image.getHeight())));
-      final Window splashScreenWindow = new Window(new Frame()) {
-          @Override
-          public void paint(Graphics g) {
-            ((Graphics2D)g).scale(scale, scale);
-            g.drawImage(image, 0, 0, this);
-          }
-        };
+    final ImageIcon image = getImageIcon(imageUrl);
+    // Try to find an image scale without getResolutionScale()
+    // because look and feel is probably not set yet
+    Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
+    final float scale = OperatingSystem.isMacOSX() || OperatingSystem.isJavaVersionGreaterOrEqual("1.9")
+        ? 1f
+        : (float)Math.min(2, Math.max(1, Math.min(screenSize.getWidth() / 4 / image.getIconWidth(), screenSize.getHeight() / 4 / image.getIconHeight())));
+    final Window splashScreenWindow = new Window(new Frame()) {
+        @Override
+        public void paint(Graphics g) {
+          ((Graphics2D)g).scale(scale, scale);
+          image.paintIcon(this, g, 0, 0);
+        }
+      };
 
-      splashScreenWindow.setSize((int)(image.getWidth() * scale), (int)(image.getHeight() * scale));
-      splashScreenWindow.setLocationRelativeTo(null);
-      splashScreenWindow.setVisible(true);
+    splashScreenWindow.setSize((int)(image.getIconWidth() * scale), (int)(image.getIconHeight() * scale));
+    splashScreenWindow.setLocationRelativeTo(null);
+    splashScreenWindow.setVisible(true);
 
-      Executors.newSingleThreadExecutor().execute(new Runnable() {
-          public void run() {
-            try {
-              Thread.sleep(500);
-              while (splashScreenWindow.isVisible()) {
-                EventQueue.invokeLater(new Runnable() {
-                    public void run() {
-                      // If a JFrame or JDialog is showing, dispose splash window
-                      try {
-                        for (Window window : (Window[])Window.class.getMethod("getWindows").invoke(null)) {
-                          if ((window instanceof JFrame || window instanceof JDialog)
-                              && window.isShowing()) {
-                            splashScreenWindow.dispose();
-                            break;
-                          }
+    Executors.newSingleThreadExecutor().execute(new Runnable() {
+        public void run() {
+          try {
+            Thread.sleep(500);
+            while (splashScreenWindow.isVisible()) {
+              EventQueue.invokeLater(new Runnable() {
+                  public void run() {
+                    // If a JFrame or JDialog is showing, dispose splash window
+                    try {
+                      for (Window window : (Window[])Window.class.getMethod("getWindows").invoke(null)) {
+                        if ((window instanceof JFrame || window instanceof JDialog)
+                            && window.isShowing()) {
+                          splashScreenWindow.dispose();
+                          break;
                         }
-                      } catch (Exception ex) {
-                        // Even if splash screen will disappear quicker,
-                        // use Frame#getFrames under Java 1.5 where Window#getWindows doesn't exist
-                        for (Frame frame : Frame.getFrames()) {
-                          if (frame.isShowing()) {
-                            splashScreenWindow.dispose();
-                            break;
-                          }
+                      }
+                    } catch (Exception ex) {
+                      // Even if splash screen will disappear quicker,
+                      // use Frame#getFrames under Java 1.5 where Window#getWindows doesn't exist
+                      for (Frame frame : Frame.getFrames()) {
+                        if (frame.isShowing()) {
+                          splashScreenWindow.dispose();
+                          break;
                         }
                       }
                     }
-                  });
-                Thread.sleep(200);
+                  }
+                });
+              Thread.sleep(200);
+            }
+          } catch (InterruptedException ex) {
+            EventQueue.invokeLater(new Runnable() {
+              public void run() {
+                splashScreenWindow.dispose();
               }
-            } catch (InterruptedException ex) {
-              EventQueue.invokeLater(new Runnable() {
-                public void run() {
-                  splashScreenWindow.dispose();
-                }
-              });
-            };
-          }
-        });
-    } catch (IOException ex) {
-      // Ignore splash screen
-    }
+            });
+          };
+        }
+      });
   }
 
   /**
@@ -1014,7 +1074,7 @@ public class SwingTools {
                                  Polyline.CapStyle capStyle,
                                  Polyline.JoinStyle joinStyle,
                                  Polyline.DashStyle dashStyle) {
-    return ShapeTools.getStroke(thickness, capStyle, joinStyle, dashStyle.getDashPattern(), 0);
+    return ShapeTools.getStroke(thickness, capStyle, joinStyle, dashStyle != Polyline.DashStyle.SOLID ? dashStyle.getDashPattern() : null, 0);
   }
 
   private static Float defaultResolutionScale;
@@ -1140,8 +1200,6 @@ public class SwingTools {
       String resolutionScaleProperty = System.getProperty("com.eteks.sweethome3d.resolutionScale");
       if (resolutionScaleProperty != null) {
         return Float.parseFloat(resolutionScaleProperty.trim());
-      } else {
-
       }
     } catch (AccessControlException ex) {
     } catch (NumberFormatException ex) {
@@ -1156,16 +1214,70 @@ public class SwingTools {
   public static ImageIcon getScaledImageIcon(URL imageUrl) {
     float resolutionScale = getResolutionScale();
     if (resolutionScale == 1) {
-      return new ImageIcon(imageUrl);
+      return getImageIcon(imageUrl);
     } else {
+      if (resolutionScale == 2) {
+        BufferedImage image = getImageAtScale(imageUrl, 2);
+        if (image != null) {
+          return new ImageIcon(image);
+        }
+      }
       try {
-        BufferedImage image = ImageIO.read(imageUrl);
-        Image scaledImage = image.getScaledInstance(Math.round(image.getWidth() * resolutionScale),
-            Math.round(image.getHeight() * resolutionScale), Image.SCALE_SMOOTH);
+        BufferedImage image = null;
+        float imageScale;
+        if (resolutionScale > 2) {
+          image = getImageAtScale(imageUrl, 2);
+        }
+        if (image == null) {
+          image = ImageIO.read(imageUrl);
+          imageScale = resolutionScale;
+        } else {
+          imageScale = resolutionScale / 2;
+        }
+        Image scaledImage = image.getScaledInstance(Math.round(image.getWidth() * imageScale),
+            Math.round(image.getHeight() * imageScale), Image.SCALE_SMOOTH);
         return new ImageIcon(scaledImage);
       } catch (IOException ex) {
         return null;
       }
     }
   }
+
+  /**
+   * Returns the image icon matching the given URL, possibly managing a multi resolution when possible.
+   */
+  private static ImageIcon getImageIcon(URL imageUrl) {
+    if (OperatingSystem.isJavaVersionGreaterOrEqual("1.9")
+        && !OperatingSystem.isMacOSX()) {
+      Image image2x = getImageAtScale(imageUrl, 2);
+      if (image2x != null) {
+        // Instantiate Java 9 BaseMultiResolutionImage class by reflection
+        // (under Mac OS X, it's the default behavior)
+        try {
+          return new ImageIcon((Image)Class.forName("java.awt.image.BaseMultiResolutionImage").getConstructor(Image[].class).
+              newInstance((Object)new Image[] {ImageIO.read(imageUrl), image2x}));
+        } catch (IOException ex) {
+        } catch (Exception ex) {
+          ex.printStackTrace();
+        }
+      }
+    }
+    return new ImageIcon(imageUrl);
+  }
+
+  /**
+   * Returns the image at the given scale from its suffix @2x, @3x...
+   */
+  private static BufferedImage getImageAtScale(URL imageUrl, int scale) {
+    try {
+      String file = imageUrl.toString();
+      int pointIndex = file.lastIndexOf('.');
+      if (pointIndex >= 0) {
+        return ImageIO.read(new URL(file.substring(0, pointIndex) + "@" + scale + "x" + file.substring(pointIndex)));
+      }
+    } catch (MalformedURLException ex) {
+    } catch (IOException ex) {
+    }
+    return null;
+  }
 }
