@@ -236,12 +236,15 @@ public class WallController implements Controller {
       getRightSideTextureController().setTexture(null);
       setRightSidePaint(null);
       setRightSideShininess(null);
-      getLeftSideBaseboardController().setVisible(null);
-      getLeftSideBaseboardController().setThickness(null);
-      getLeftSideBaseboardController().setHeight(null);
-      getLeftSideBaseboardController().setColor(null);
-      getLeftSideBaseboardController().getTextureController().setTexture(null);
-      getLeftSideBaseboardController().setPaint(null);
+      getRightSideBaseboardController().setVisible(null);
+      getRightSideBaseboardController().setThickness(null);
+      getRightSideBaseboardController().setHeight(null);
+      getRightSideBaseboardController().setColor(null);
+      getRightSideBaseboardController().getTextureController().setTexture(null);
+      getRightSideBaseboardController().setPaint(null);
+      setPattern(null);
+      setTopColor(null);
+      setTopPaint(null);
       setRectangularWallHeight(null);
       setSlopingWallHeightAtStart(null);
       setSlopingWallHeightAtEnd(null);
