@@ -136,8 +136,8 @@ public class PhotoCreationTest extends ComponentTestFixture {
     compass.setTimeZone("Europe/Paris");
     GregorianCalendar calendar = new GregorianCalendar(2010, GregorianCalendar.SEPTEMBER, 1, 14, 30, 10);
     calendar.setTimeZone(TimeZone.getTimeZone(compass.getTimeZone()));
-    TestUtilities.assertEqualsWithinEpsilon("Incorrect azimuth", 3.383972f, compass.getSunAzimuth(calendar.getTimeInMillis()), 1E-5f);
-    TestUtilities.assertEqualsWithinEpsilon("Incorrect elevation", 0.915943f, compass.getSunElevation(calendar.getTimeInMillis()), 1E-5f);
+    assertEquals("Incorrect azimuth", 3.383972f, compass.getSunAzimuth(calendar.getTimeInMillis()), 1E-5f);
+    assertEquals("Incorrect elevation", 0.915943f, compass.getSunElevation(calendar.getTimeInMillis()), 1E-5f);
     
     compass = new Compass(0, 0, 2);
     compass.setLatitude((float)Math.toRadians(40));
@@ -145,8 +145,8 @@ public class PhotoCreationTest extends ComponentTestFixture {
     compass.setTimeZone("Asia/Tokyo");
     calendar = new GregorianCalendar(2011, GregorianCalendar.JANUARY, 31, 8, 0, 0);
     calendar.setTimeZone(TimeZone.getTimeZone(compass.getTimeZone()));
-    TestUtilities.assertEqualsWithinEpsilon("Incorrect azimuth", 2.44565f, compass.getSunAzimuth(calendar.getTimeInMillis()), 1E-5f);
-    TestUtilities.assertEqualsWithinEpsilon("Incorrect elevation", 0.38735f, compass.getSunElevation(calendar.getTimeInMillis()), 1E-5f);
+    assertEquals("Incorrect azimuth", 2.44565f, compass.getSunAzimuth(calendar.getTimeInMillis()), 1E-5f);
+    assertEquals("Incorrect elevation", 0.38735f, compass.getSunElevation(calendar.getTimeInMillis()), 1E-5f);
   }
   
   public void testPhotoCreation() throws InterruptedException, ComponentSearchException, NoSuchFieldException, IllegalAccessException, InvocationTargetException, IOException {
@@ -184,10 +184,8 @@ public class PhotoCreationTest extends ComponentTestFixture {
     for (int i = qualitySlider.getMinimum(); i <= qualitySlider.getMaximum(); i++) {
       sliderTester.actionSlide(qualitySlider, i);
       // Test image creation at each quality 
-      tester.click(createButton);
-      if (i == qualitySlider.getMinimum()) {
-        assertFalse("Rendering didn't start", saveButton.isEnabled());
-      }
+      tester.actionClick(createButton);
+      assertFalse("Rendering didn't start", saveButton.isEnabled());
       // Wait image is generated
       for (int j = 0; j < 1000 && !saveButton.isEnabled(); j++) {
         Thread.sleep(100);
@@ -197,7 +195,7 @@ public class PhotoCreationTest extends ComponentTestFixture {
           preferences.getLocalizedString(PhotoPanel.class, "savePhotoDialog.title"),
           photoCreationDialog, tester);
     }
-    tester.click(closeButton);
+    tester.actionClick(closeButton);
     tester.close(frame);
   }
 
@@ -226,7 +224,7 @@ public class PhotoCreationTest extends ComponentTestFixture {
       sliderTester.actionSlide(qualitySlider, i);
       // Test image creation at quality 1 and 3 
       assertFalse("Progress bar is showing", progressBar.isShowing());
-      tester.click(createButton);
+      tester.actionClick(createButton);
       assertTrue("Progress bar isn't showing", progressBar.isShowing());
       // Wait image is generated
       for (int j = 0; j < 1000 && !saveButton.isEnabled(); j++) {
@@ -237,7 +235,7 @@ public class PhotoCreationTest extends ComponentTestFixture {
           preferences.getLocalizedString(VideoPanel.class, "saveVideoDialog.title"),
           videoCreationDialog, tester);
     }
-    tester.click(closeButton);
+    tester.actionClick(closeButton);
     tester.close(frame);
   }
   
@@ -296,7 +294,7 @@ public class PhotoCreationTest extends ComponentTestFixture {
     assertTrue("Couldn't create tmp directory", tmpDirectory.mkdir());
     String mediaBaseName = "test";
     // Show save dialog box
-    tester.click(saveButton);
+    tester.actionClick(saveButton);
     // Wait for file chooser to be shown
     tester.waitForFrameShowing(new AWTHierarchy(), fileDialogTitle);
     // Check dialog box is displayed
