@@ -31,6 +31,7 @@ import javax.swing.JSpinner;
 import javax.swing.JSpinner.DefaultEditor;
 import javax.swing.undo.UndoableEditSupport;
 
+import junit.framework.ComparisonFailure;
 import junit.framework.TestCase;
 
 import com.eteks.sweethome3d.io.DefaultUserPreferences;
@@ -221,8 +222,12 @@ public class UserPreferencesPanelTest extends TestCase {
     // Test formats without unit
     assertEquals("Wrong conversion", "102", LengthUnit.CENTIMETER.getFormat().format(102));
     assertEquals("Wrong conversion", "1,02", LengthUnit.METER.getFormat().format(102));
-    // \u00a0 is a no-break space
-    assertEquals("Wrong conversion", "1\u00a0020", LengthUnit.MILLIMETER.getFormat().format(102));
+    // \u00a0 and \u202f are a no-break spaces and are different depending on Java version
+    try {
+      assertEquals("Wrong conversion", "1\u00a0020", LengthUnit.MILLIMETER.getFormat().format(102));
+    } catch (ComparisonFailure ex) {
+      assertEquals("Wrong conversion", "1\u202f020", LengthUnit.MILLIMETER.getFormat().format(102));
+    }
     assertEquals("Wrong conversion", "0'11\"",
         LengthUnit.INCH.getFormat().format(LengthUnit.inchToCentimeter(11)));
     assertEquals("Wrong conversion", "1'11\"",
@@ -241,8 +246,12 @@ public class UserPreferencesPanelTest extends TestCase {
     // Test formats with unit
     assertEquals("Wrong conversion", "102 cm", LengthUnit.CENTIMETER.getFormatWithUnit().format(102));
     assertEquals("Wrong conversion", "1,02 m", LengthUnit.METER.getFormatWithUnit().format(102));
-    // \u00a0 is a no-break space
-    assertEquals("Wrong conversion", "1\u00a0020 mm", LengthUnit.MILLIMETER.getFormatWithUnit().format(102));
+    // \u00a0 and \u202f are a no-break spaces
+    try {
+      assertEquals("Wrong conversion", "1\u00a0020 mm", LengthUnit.MILLIMETER.getFormatWithUnit().format(102));
+    } catch (ComparisonFailure ex) {
+      assertEquals("Wrong conversion", "1\u202f020 mm", LengthUnit.MILLIMETER.getFormatWithUnit().format(102));
+    }
     assertEquals("Wrong conversion", "0'11\"",
         LengthUnit.INCH.getFormatWithUnit().format(LengthUnit.inchToCentimeter(11)));
     assertEquals("Wrong conversion", "1'11\"",
@@ -254,51 +263,51 @@ public class UserPreferencesPanelTest extends TestCase {
     assertEquals("Wrong parsing", 102f, LengthUnit.CENTIMETER.getFormat().parseObject("102"));
     assertEquals("Wrong parsing", 102f, LengthUnit.METER.getFormat().parseObject("1,02"));
     assertEquals("Wrong parsing", 102f, LengthUnit.MILLIMETER.getFormat().parseObject("1020"));
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(0.125f),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(0.125f),
         ((Number)LengthUnit.INCH_DECIMALS.getFormat().parseObject("0,125")).floatValue(), 1E-10f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(0.125f),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(0.125f),
         ((Number)LengthUnit.INCH_DECIMALS.getFormat().parseObject("0,125\"")).floatValue(), 1E-10f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(11),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(11),
         ((Number)LengthUnit.INCH.getFormat().parseObject("0'11\"")).floatValue(), 1E-10f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(10 + 12),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(10 + 12),
         ((Number)LengthUnit.INCH.getFormat().parseObject("1 ' 10 \"")).floatValue(), 1E-10f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(24),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(24),
         ((Number)LengthUnit.INCH.getFormat().parseObject("2'")).floatValue(), 1E-10f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(11),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(11),
         ((Number)LengthUnit.INCH.getFormat().parseObject("11\"")).floatValue(), 1E-10f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(11),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(11),
         ((Number)LengthUnit.INCH.getFormat().parseObject("11")).floatValue(), 1E-10f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(11.125f),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(11.125f),
         ((Number)LengthUnit.INCH.getFormat().parseObject("11,125")).floatValue(), 1E-10f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(12 + 11 + 3 * 0.125f),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(12 + 11 + 3 * 0.125f),
         ((Number)LengthUnit.INCH.getFormat().parseObject("1'11\u215c\"")).floatValue(), 1E-10f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(12 + 11 + 3 * 0.125f),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(12 + 11 + 3 * 0.125f),
         ((Number)LengthUnit.INCH.getFormat().parseObject("1'11 3/8\"")).floatValue(), 1E-10f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(12 + 11 + 3 * 0.125f),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(12 + 11 + 3 * 0.125f),
         ((Number)LengthUnit.INCH.getFormat().parseObject("1' 11 \u215c")).floatValue(), 1E-10f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(-(12 + 11 + 3 * 0.125f)),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(-(12 + 11 + 3 * 0.125f)),
         ((Number)LengthUnit.INCH.getFormat().parseObject("-1' 11 \u215c")).floatValue(), 1E-10f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(-(12 + 11 + 3 * 0.125f)),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(-(12 + 11 + 3 * 0.125f)),
         ((Number)LengthUnit.INCH.getFormat().parseObject("-1'11\u215c")).floatValue(), 1E-10f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(-(12 + 11 + 3 * 0.125f)),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(-(12 + 11 + 3 * 0.125f)),
         ((Number)LengthUnit.INCH.getFormat().parseObject("-1'11 3/8")).floatValue(), 1E-10f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(-(12 + 3 * 0.125f)),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(-(12 + 3 * 0.125f)),
         ((Number)LengthUnit.INCH.getFormat().parseObject("-1'0\u215c")).floatValue(), 1E-10f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(-(12 + 3 * 0.125f)),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(-(12 + 3 * 0.125f)),
         ((Number)LengthUnit.INCH.getFormat().parseObject("-1'0 3/8")).floatValue(), 1E-10f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(-(11 + 3 * 0.125f)),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(-(11 + 3 * 0.125f)),
         ((Number)LengthUnit.INCH.getFormat().parseObject("-0'11\u215c")).floatValue(), 1E-4f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(-(11 + 3 * 0.125f)),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(-(11 + 3 * 0.125f)),
         ((Number)LengthUnit.INCH.getFormat().parseObject("-0'11 3/8")).floatValue(), 1E-4f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(-(3 * 0.125f)),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(-(3 * 0.125f)),
         ((Number)LengthUnit.INCH.getFormat().parseObject("-0'0\u215c")).floatValue(), 1E-10f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(-(3 * 0.125f)),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(-(3 * 0.125f)),
         ((Number)LengthUnit.INCH.getFormat().parseObject("-0' 0 \u215c\"")).floatValue(), 1E-10f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(-0.125f),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(-0.125f),
         ((Number)LengthUnit.INCH.getFormat().parseObject("-0'0,125")).floatValue(), 1E-10f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  LengthUnit.inchToCentimeter(-0.125f),
+    assertEquals("Wrong conversion",  LengthUnit.inchToCentimeter(-0.125f),
         ((Number)LengthUnit.INCH.getFormat().parseObject("-0,125")).floatValue(), 1E-10f);
-    TestUtilities.assertEqualsWithinEpsilon("Wrong conversion",  0,
+    assertEquals("Wrong conversion",  0,
         ((Number)LengthUnit.INCH.getFormat().parseObject("-0'0")).floatValue(), 1E-10f);
     try {
       LengthUnit.INCH.getFormat().parseObject("'");
